/*
 * Copyright (C) 2020 olie.xdev <olie.xdev@googlemail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>
 */

package com.health.openworkout.core.datatypes;

import android.content.Context;

import androidx.annotation.Keep;
import androidx.room.ColumnInfo;
import androidx.room.Entity;
import androidx.room.Ignore;
import androidx.room.PrimaryKey;

import com.health.openworkout.R;
import com.health.openworkout.core.OpenWorkout;

@Keep
@Entity
public class WorkoutItem implements Comparable<WorkoutItem>, Cloneable {
    @PrimaryKey(autoGenerate = true)
    private long workoutItemId;

    @ColumnInfo
    private long workoutSessionId;
    @ColumnInfo
    private long orderNr;
    @ColumnInfo
    private String name;
    @ColumnInfo
    private String description;
    @ColumnInfo
    private long elapsedTime; // in sec
    @ColumnInfo
    private String imagePath;
    @ColumnInfo
    private boolean isImagePathExternal;
    @ColumnInfo
    private boolean isVideoMode;
    @ColumnInfo
    private String videoPath;
    @ColumnInfo
    private boolean isVideoPathExternal;
    @ColumnInfo
    private int prepTime; // in sec
    @ColumnInfo
    private int workoutTime; // in sec
    @ColumnInfo
    private int breakTime; // in sec
    @ColumnInfo
    private int repetitionCount;
    @ColumnInfo
    private boolean isTimeMode;
    @ColumnInfo
    private boolean finished;

    @Ignore
    private transient final Context context;

    public WorkoutItem() {
        context = OpenWorkout.getInstance().getContext();
        name = "<" + context.getString(R.string.label_new_workout_item) + ">";
        description = "<" + context.getString(R.string.label_new_workout_item) + ">";
        orderNr = -1L;
        prepTime = 5;
        workoutTime = 30;
        breakTime = 30;
        repetitionCount = 5;
        isTimeMode = true;
        finished = false;
        isVideoMode = true;
        isVideoPathExternal = false;
        videoPath = "idle.mp4";
        isImagePathExternal = false;
        imagePath = "idle.png";
    }

    @Override
    public WorkoutItem clone() {
        WorkoutItem clone;
        try {
            clone = (WorkoutItem) super.clone();
        }
        catch (CloneNotSupportedException e) {
            throw new RuntimeException("failed to clone WorkoutItem", e);
        }

        return clone;
    }

    public final Context getContext() {
        return context;
    }

    public void setWorkoutItemId(long workoutItemId) {
        this.workoutItemId = workoutItemId;
    }

    public long getWorkoutItemId() {
        return workoutItemId;
    }

    public void setWorkoutSessionId(long workoutSessionId) {
        this.workoutSessionId = workoutSessionId;
    }

    public long getWorkoutSessionId() {
        return workoutSessionId;
    }

    public long getOrderNr() {
        return orderNr;
    }

    public void setOrderNr(long orderNr) {
        this.orderNr = orderNr;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public long getElapsedTime() {
        return elapsedTime;
    }

    public void setElapsedTime(long elapsedTime) {
        this.elapsedTime = elapsedTime;
    }

    public String getImagePath() {
        return imagePath;
    }

    public void setImagePath(String imagePath) {
        this.imagePath = imagePath;
    }

    public void setImagePath(int resId) {
        imagePath = context.getResources().getResourceEntryName(resId);
    }

    public boolean isImagePathExternal() {
        return isImagePathExternal;
    }

    public void setImagePathExternal(boolean imagePathExternal) {
        isImagePathExternal = imagePathExternal;
    }

    public boolean isVideoMode() {
        return isVideoMode;
    }

    public void setVideoMode(boolean videoMode) {
        isVideoMode = videoMode;
    }

    public String getVideoPath() {
        return videoPath;
    }

    public void setVideoPath(String videoPath) {
        this.videoPath = videoPath;
    }

    public boolean isVideoPathExternal() {
        return isVideoPathExternal;
    }

    public void setVideoPathExternal(boolean videoPathExternal) {
        isVideoPathExternal = videoPathExternal;
    }

    public int getPrepTime() {
        return prepTime;
    }

    public void setPrepTime(int prepTime) {
        this.prepTime = prepTime;
    }

    public int getWorkoutTime() {
        return workoutTime;
    }

    public void setWorkoutTime(int workoutTime) {
        this.workoutTime = workoutTime;
    }

    public int getBreakTime() {
        return breakTime;
    }

    public void setBreakTime(int breakTime) {
        this.breakTime = breakTime;
    }

    public int getRepetitionCount() {
        return repetitionCount;
    }

    public void setRepetitionCount(int repetitionCount) {
        this.repetitionCount = repetitionCount;
    }

    public boolean isTimeMode() {
        return isTimeMode;
    }

    public void setTimeMode(boolean timeMode) {
        isTimeMode = timeMode;
    }

    public boolean isFinished() {
        return finished;
    }

    public void setFinished(boolean finished) {
        this.finished = finished;

        if (!finished) {
            elapsedTime = 0L;
        }
    }

    @Override
    public int compareTo(WorkoutItem o) {
        if (this.orderNr == -1L || o.orderNr == -1L) {
            return (int)(this.workoutItemId - o.workoutItemId);
        }

        return (int)(this.orderNr - o.orderNr);
    }
}
